-- BASIC CONFIGURATION

-- array of doorphone numbers
-- for typical configuration with registration: use just phone number, for peer-to-peer: full URIs might be needed
-- URIs/numbers can be copied from tSIP call history
local DOORPHONE_NUMBERS = {
	"sip:3333@sip2sip.info;transport=udp",
	"148"
}

local DOORPHONE_RTSP_URL = "rtsp://127.0.0.1:8554/"	-- VLC as RTSP server
-- local DOORPHONE_RTSP_URL = "rtsp://127.0.0.1:554/BigBuckBunnyTrailer.webm"	-- live555 mediaServer.exe, webm VP8 in the same folder
local RTSP_TRANSPORT = "udp"

-- "big" button working as canvas where video would be displayed
local VIDEO_DISPLAY_BUTTON_ID = 100

-- END OF BASIC CONFIGURATION

local execSourceType = GetExecSourceType()
if execSourceType ~= 2 then
	print("Error: mpv/doorphone script should be assigned to \"on call state\" event!\n")
	return
end

local callId = GetExecSourceId()
local peer = GetCallPeer(callId)

local doorphoneFound = false
for i = 1, #DOORPHONE_NUMBERS do
	if peer == DOORPHONE_NUMBERS[i] then
		doorphoneFound = true
		break
	end
end

if doorphoneFound == false then
	print(string.format("doorphone script: peer = %s, ignoring\n", peer))
	return
end

local VAR_NAME = "tSIP_mpv_for_doorphone_CREATED"
local PLAYER_NAME = "DOORPHONE_PLAYER"
local once, onceIsSet = GetVariable(VAR_NAME)
if onceIsSet == 0 then
	print("Creating mpv instance\n")
	SetVariable(VAR_NAME, "1")
	local handle = GetButtonHandle(VIDEO_DISPLAY_BUTTON_ID) -- button ID to use for display
	PluginSendMessageText("tSIP_mpv.dll", PLAYER_NAME .. string.format(" CREATE %x", handle))
	-- assuming that audio would be received only through regular SIP/RTP call,
	-- mute audio from RTSP
	PluginSendMessageText("tSIP_mpv.dll", PLAYER_NAME .. " VOLUME 0")
	PluginSendMessageText("tSIP_mpv.dll", PLAYER_NAME .. " SET_PROPERTY_STRING rtsp-transport " .. RTSP_TRANSPORT)
	PluginSendMessageText("tSIP_mpv.dll", PLAYER_NAME .. " SET_PROPERTY_STRING profile low-latency")	
end

local callState = GetCallState(callId)
if callState == 0 then	-- call closed
	print("Doorphone script: stopping video player\n");
	PluginSendMessageText("tSIP_mpv.dll", PLAYER_NAME .. " STOP")
elseif callState == 1 then	-- call incoming
	print(string.format("Doorphone script: starting video player on incoming call, button = %d\n", VIDEO_DISPLAY_BUTTON_ID));
	PluginSendMessageText("tSIP_mpv.dll", PLAYER_NAME .. " PLAY " .. DOORPHONE_RTSP_URL)
	PluginSendMessageText("tSIP_mpv.dll", PLAYER_NAME .. " VOLUME 0")
elseif callState == 2 then	-- call outgoing
	print(string.format("Doorphone script: starting video player on outgoing call, button = %d\n", VIDEO_DISPLAY_BUTTON_ID));
	PluginSendMessageText("tSIP_mpv.dll", PLAYER_NAME .. " PLAY " .. DOORPHONE_RTSP_URL)
	PluginSendMessageText("tSIP_mpv.dll", PLAYER_NAME .. " VOLUME 0")
end
